Search for the top twenty wikipedia pages that match a given query. This function will return a dataframe with the
names of the matched articles and the first paragraph of content.
Usage
search_wiki(search_term, clean = TRUE)
Arguments
search_term
The search term you would like to use.
clean
Should getwiki remove html tags from the returned text?
Value
search_term will return a dataframe of the top twenty search results. The "title" column will be the title
of the articles and the "content" column will be the first paragraph from those articles.